@@ -114,15 +114,19 @@ def registration_callback(vreg):
         except (ObjectNotFound, RegistryNotFound):
             return # no transactionlog configuration registred
 
-        if config.ETYPES:
-            vreg.register_and_replace(RecordEntity, RecordEntity)
+        try:
+            if config.ETYPES:
+                vreg.register_and_replace(RecordEntity, RecordEntity)
 
-            RecordEntity.__select__ = RecordEntity.__select__ & is_instance(*config.ETYPES.keys())
+                RecordEntity.__select__ = RecordEntity.__select__ & is_instance(*config.ETYPES.keys())
 
-        if config.RDEFS:
-            selectors = (match_rtype(rtype,
-                                     frometypes=(frometype,) if frometype else None,
-                                     toetypes=(toetype,) if toetype else None)
-                         for frometype, rtype, toetype in config.RDEFS)
-            RecordRelation.__select__ = Hook.__select__ & reduce(op.or_, selectors)
-            vreg.register_and_replace(RecordRelation, RecordRelation)
+            if config.RDEFS:
+                selectors = (match_rtype(rtype,
+                                         frometypes=(frometype,) if frometype else None,
+                                         toetypes=(toetype,) if toetype else None)
+                             for frometype, rtype, toetype in config.RDEFS)
+                RecordRelation.__select__ = Hook.__select__ & reduce(op.or_, selectors)
+                vreg.register_and_replace(RecordRelation, RecordRelation)
+        except AttributeError:
+            print 'critical failure to register transaction log'
+            print '(unless this is a "cubicweb-ctl i18ncube" or such command)'
