@@ -16,3 +16,24 @@
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """cubicweb-transactionlog views/forms/actions/components for web ui"""
+
+import cPickle
+import zlib
+
+from logilab.mtconverter import xml_escape
+
+from cwtags.tag import div
+ 
+from cubicweb.predicates import is_instance
+from cubicweb.view import EntityView
+
+
+class TLogOneLine(EntityView):
+    __regid__ = 'incontext'
+    __select__ = is_instance('TransactionLog')
+
+    def entity_call(self, entity):
+        w = self.w
+        for line in cPickle.loads(zlib.decompress(entity.data.getvalue())):
+            with div(w):
+                w(xml_escape(unicode(repr(line))))
